@@ -113,6 +113,12 @@ MainWindow::MainWindow( std::unique_ptr<Session> session,
     signalMux_.connect( SIGNAL( loadingFinished( LoadingStatus ) ),
             this, SLOT( handleLoadingFinished( LoadingStatus ) ) );
 
+    // Register for checkbox changes
+    signalMux_.connect( SIGNAL( searchRefreshChanged( int ) ),
+            this, SLOT( handleSearchRefreshChanged( int ) ) );
+    signalMux_.connect( SIGNAL( ignoreCaseChanged( int ) ),
+            this, SLOT( handleIgnoreCaseChanged( int ) ) );
+
     // Configure the main tabbed widget
     mainTabWidget_.setDocumentMode( true );
     mainTabWidget_.setMovable( true );
@@ -619,6 +625,18 @@ memory to hold the index for this file. The file will now be closed." );
     // mainTabWidget_.setEnabled( true );
 }
 
+void MainWindow::handleSearchRefreshChanged( int state )
+{
+    auto config = Persistent<Configuration>( "settings" );
+    config->setSearchAutoRefreshDefault( state == Qt::Checked );
+}
+
+void MainWindow::handleIgnoreCaseChanged( int state )
+{
+    auto config = Persistent<Configuration>( "settings" );
+    config->setSearchIgnoreCaseDefault( state == Qt::Checked );
+}
+
 void MainWindow::closeTab( int index )
 {
     auto widget = dynamic_cast<CrawlerWidget*>(
@@ -674,6 +692,33 @@ void MainWindow::loadFileNonInteractive( const QString& file_name )
         << file_name.toStdString() << " )";
 
     loadFile( file_name );
+
+    // Try to get the window to the front
+    // This is a bit of a hack but has been tested on:
+    // Qt 5.3 / Gnome / Linux
+    // Qt 4.8 / Win7
+#ifdef _WIN32
+    // Hack copied from http://qt-project.org/forums/viewthread/6164
+    ::SetWindowPos((HWND) effectiveWinId(), HWND_TOPMOST,
+            0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE | SWP_SHOWWINDOW);
+    ::SetWindowPos((HWND) effectiveWinId(), HWND_NOTOPMOST,
+            0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE | SWP_SHOWWINDOW);
+#else
+    Qt::WindowFlags window_flags = windowFlags();
+    window_flags |= Qt::WindowStaysOnTopHint;
+    setWindowFlags( window_flags );
+#endif
+
+    activateWindow();
+    raise();
+
+#ifndef _WIN32
+    window_flags = windowFlags();
+    window_flags &= ~Qt::WindowStaysOnTopHint;
+    setWindowFlags( window_flags );
+#endif
+
+    showNormal();
 }
 
 void MainWindow::newVersionNotification( const QString& new_version )
